import "core-js/modules/es6.function.name";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
var _targets = [];
/**
 * Configures the PWA to broadcast events to all specified targets.  Once configured, You can call any method on
 * on all targets by calling `analytics.fire(method, ...params)`.  
 * 
 * Example:
 * 
 *  // src/analytics.js
 * 
 *  import { configureAnalytics } from 'react-storefront/analytics'
 *  import GoogleTagManagerTarget from 'react-storefront-analytics/GoogleTagManagerTarget'
 *  import MerkleSearchTarget from 'react-storefront-analytics/MerkleSearchTarget'
 * 
 *  configureAnalytics(
 *    new GoogleTagManagerTarget({ apiKey: 'my_gtm_api_key' }),
 *    new MerkleSearchTarget({ apiKey: 'my_merkle_api_key' })
 *  )
 * 
 * // then, to broadcast an analytics event to all targets:
 * 
 * import analytics from 'react-storefront/analytics'
 * 
 * analytics.fire('someEvent', { foo: 'bar' }) // this will call the 'someEvent(data)' method on all configured targets and pass { foo: 'bar' } as the data argument.
 * 
 * @param {AnalyticsTarget[]} targets An array of targets to notify when analytics events occur
 * @return {AnalyticsProvider}
 */

export function configureAnalytics() {
  for (var _len = arguments.length, targets = new Array(_len), _key = 0; _key < _len; _key++) {
    targets[_key] = arguments[_key];
  }

  _targets = targets;
}
export function getTargets() {
  return _targets;
}

function fire(event) {
  for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    args[_key2 - 1] = arguments[_key2];
  }

  for (var _i = 0; _i < _targets.length; _i++) {
    var target = _targets[_i];
    var fn = target[event];

    if (fn) {
      fn.apply(target, args);
    } else {
      if (typeof event === 'string') {
        console.warn("".concat(target.constructor.name, " does not support ").concat(event));
      }
    }
  }
}
/**
 * This module's default export is a single entry point for broadcasting analytics events to all targets configured via `configureAnalytics`.
 * Each target represents a tag manager or other analytics service to which the application should send data.
 * 
 * Example:
 * 
 *  // src/analytics.js
 * 
 *  import { configureAnalytics } from 'react-storefront/analytics'
 *  import GoogleTagManagerTarget from 'react-storefront-analytics/GoogleTagManagerTarget'
 *  import MerkleSearchTarget from 'react-storefront-analytics/MerkleSearchTarget'
 * 
 *  configureAnalytics(
 *    new GoogleTagManagerTarget({ apiKey: 'my_gtm_api_key' }),
 *    new MerkleSearchTarget({ apiKey: 'my_merkle_api_key' })
 *  )
 * 
 */


var analytics = {
  fire: fire
};

if (typeof Proxy !== 'undefined') {
  analytics = new Proxy({
    fire: fire
  }, {
    get: function get(o, method) {
      if (method === 'fire') {
        return fire;
      } else if (method === 'toString') {
        return function () {
          return 'AnalyticsProxy';
        };
      } else {
        return fire.bind(null, method);
      }
    }
  });
}

export default analytics;
//# sourceMappingURL=analytics.js.map